def starting():
    pygame.init()
    clock = pygame.time.Clock()
